#
# spec file for package python-mizani
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-mizani
Version:        0.11.4
Release:        1.1
Summary:        Scales for Python
License:        BSD-3-Clause
URL:            https://github.com/has2k1/mizani
Source:         https://files.pythonhosted.org/packages/source/m/mizani/mizani-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-matplotlib >= 3.1.1
Requires:       python-numpy
Requires:       python-palettable
Requires:       python-pandas >= 1.1.0
Requires:       python-scipy >= 1.5.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module backports.zoneinfo if %python-base < 3.9}
BuildRequires:  %{python_module matplotlib >= 3.1.1}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module palettable}
BuildRequires:  %{python_module pandas >= 1.1.0}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 1.5.0}
# /SECTION
%python_subpackages

%description
Mizani is a scales package for graphics.

%prep
%setup -q -n mizani-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Broken test in i586
donttest="mizani.breaks.log_breaks"
# test_breaks needs https://github.com/matplotlib/matplotlib/issues/22305 fixed in next mpl
%pytest --ignore mizani/tests/test_breaks.py -k "not ($donttest)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/mizani
%{python_sitelib}/mizani-%{version}*-info

%changelog
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.4:
  * Fixed :class:`~mizani.bounds.squish` and
    :class:`~mizani.bounds.squish_infinite` so that they do not
    reuse numpy arrays. The users object is not modified.
  * Fixed bug when calculating monthly breaks where when the limits
    are narrow and do not align with the start and end of the
    month, there were no dates returned.
  * Added the ability to create reversed colormap for
    :class:`~mizani.palettes.cmap_pal` and
    :class:`~mizani.palettes.cmap_d_pal` using the matplotlib
    convention of `name_r`.
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.1:
  * Fix :class:`mizani.palettes.brewer_pal` to return exact colors
    in the when the requested colors are less than or equal to
    those in the palette.
  * Add all matplotlib colormap and make them avalaible from
    :class:`~mizani.palettes.cmap_pal` and
    :class:`~mizani.palettes.cmap_d_pal` (:issue:`39`).
  * Added :class:`~mizani.breaks.breaks_symlog` to calculate
    breaks for the symmetric logarithm transformation.
  * The default `big_mark` for :class:`~mizani.labels.label_number`
    has been changed from a comma to nothing.
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 0.11.0:
  * Removed FutureWarnings when using pandas 2.1.0
  * Added :class:`~mizani.breaks.breaks_symlog` to calculate
    breaks for the symmetric logarithm transformation.
  * The default `big_mark` for :class:`~mizani.labels.label_number`
    has been changed from a comma to nothing.
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0:
  * :class:`~mizani.formatters.mpl_format` has been removed,
    :class:`~mizani.formatters.number_format` takes its place.
  * :class:`~mizani.breaks.mpl_breaks` has been removed,
    :class:`~mizani.breaks.extended_breaks` has always been
    the default and it is sufficient.
  * matplotlib has been removed as a dependency of mizani.
  * mizani now requires python 3.9 and above.
  * The units parameter for of :class:`~mizani.formatters.timedelta_format`
    now accepts the values `"min", "day", "week", "month"`,
  instead of `"m", "d", "w", "M"`.
  * The naming convention for break formatting methods has changed
    from `*_format` to `label_*`.
  * The naming convention for break calculating methods has changed
    from `*_breaks` to `breaks_*`. Specifically these methods have
    been renamed.
  * `log_breaks` is now :class:`~mizani.breaks.breaks_log`
  * `trans_minor_breaks` is now :class:`~mizani.breaks.minor_breaks_trans`
  * `date_breaks` is now :class:`~mizani.breaks. breaks_date`
* Mon Mar  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Disable broken test in i586 mizani.breaks.log_breaks, it's broken
  because it expect:
    array([     1000,    10000,   100000,  1000000])
  but got:
    array([     1000,    10000,   100000,  1000000], dtype=int32)
* Tue Feb 14 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.8.1:
  * Fixed regression bug in mizani.formatters.log_format for
    where formatting for bases 2, 8 and 16 would fail if the values were
    float-integers.
  * mizani.formatters.log_format now uses exponent notation
    for bases other than base 10.
  * The lut parameter of mizani.palettes.cmap_pal and
    mizani.palettes.cmap_d_pal has been deprecated and will
    removed in a future version.
  * mizani.transforms.datetime_trans gained parameter tz
    that controls the timezone of the transformation.
  * mizani.formatters.log_format gained boolean parameter
    mathtex for TeX values as understood by matplotlib instead of
    values in scientific notation.
  * Fixed bug in mizani.bounds.zero_range where uint64
    values would cause a RuntimeError.
* Fri Feb  4 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.7.3
  * Fixed log_breaks for narrow range if base=2 (:issue:`76`).
* Thu Feb 18 2021 Ben Greiner <code@bnavigator.de>
- Update to version 0.7.2
  * Fixed bug in :func:`~mizani.bounds.rescale_max` to properly
    handle values whose maximum is zero.
- Skip python36 build: NumPy 1.20 in Tumbleweed dropped support
  for Python 3.6 (NEP 29)
- SciPy is not a runtime requirement
* Fri Jul 10 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.7.1
  * Fixed issue with :class:`mizani.formatters.log_breaks` where non-linear
    breaks could not be generated if the limits where greater than the largest
    integer sys.maxsize.
  * Fixed :func:`mizani.palettes.gradient_n_pal` to return nan for nan values.
  * Fixed :func:`mizani.scales.scale_discrete.train` when training categoricals
    to maintain the order.
* Tue Dec  3 2019 Todd R <toddrme2178@gmail.com>
- Initial version
